package betterquesting.client.gui2.editors;

import betterquesting.api.client.gui.misc.INeedsRefresh;
import betterquesting.api.client.gui.misc.IVolatileScreen;
import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.tasks.ITask;
import betterquesting.api2.client.gui.GuiScreenCanvas;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.controls.PanelTextField;
import betterquesting.api2.client.gui.controls.filters.FieldFilterString;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiAlign;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.GuiTransform;
import betterquesting.api2.client.gui.panels.CanvasTextured;
import betterquesting.api2.client.gui.panels.bars.PanelVScrollBar;
import betterquesting.api2.client.gui.panels.content.PanelLine;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.panels.lists.CanvasScrolling;
import betterquesting.api2.client.gui.panels.lists.CanvasSearch;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.registry.IFactoryData;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.client.gui2.editors.nbt.GuiNbtEditor;
import betterquesting.network.handlers.NetQuestEdit;
import betterquesting.questing.QuestDatabase;
import betterquesting.questing.tasks.TaskRegistry;
import com.mojang.realmsclient.gui.ChatFormatting;
import java.util.ArrayDeque;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
import org.lwjgl.util.vector.Vector4f;

/* loaded from: betterquesting_client_gui2_editors.jar:betterquesting/client/gui2/editors/GuiTaskEditor.class */
public class GuiTaskEditor extends GuiScreenCanvas implements IPEventListener, IVolatileScreen, INeedsRefresh {
    private CanvasScrolling qtList;
    private IQuest quest;
    private final int qID;

    public GuiTaskEditor(GuiScreen parent, IQuest quest) {
        super(parent);
        this.quest = quest;
        this.qID = QuestDatabase.INSTANCE.getID(quest);
    }

    public void refreshGui() {
        this.quest = (IQuest) QuestDatabase.INSTANCE.getValue(this.qID);
        if (this.quest == null) {
            this.field_146297_k.func_147108_a(this.parent);
        } else {
            refreshTasks();
        }
    }

    public void initPanel() {
        super.initPanel();
        if (this.qID < 0) {
            this.field_146297_k.func_147108_a(this.parent);
            return;
        }
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        CanvasTextured cvBackground = new CanvasTextured(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 0, 0, 0), 0), PresetTexture.PANEL_MAIN.getTexture());
        addPanel(cvBackground);
        PanelTextBox panTxt = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0), QuestTranslation.translate("betterquesting.title.edit_tasks", new Object[0])).setAlignment(1);
        panTxt.setColor(PresetColor.TEXT_HEADER.getColor());
        cvBackground.addPanel(panTxt);
        cvBackground.addPanel(new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, -100, -16, 200, 16, 0), 0, QuestTranslation.translate("gui.back", new Object[0])));
        CanvasSearch<IFactoryData<ITask, NBTTagCompound>, IFactoryData<ITask, NBTTagCompound>> cvRegSearch = new CanvasSearch<IFactoryData<ITask, NBTTagCompound>, IFactoryData<ITask, NBTTagCompound>>(new GuiTransform(GuiAlign.HALF_RIGHT, new GuiPadding(8, 48, 24, 32), 0)) { // from class: betterquesting.client.gui2.editors.GuiTaskEditor.1
            protected /* bridge */ /* synthetic */ void queryMatches(Object obj, String str, ArrayDeque arrayDeque) {
                queryMatches((IFactoryData<ITask, NBTTagCompound>) obj, str, (ArrayDeque<IFactoryData<ITask, NBTTagCompound>>) arrayDeque);
            }

            protected Iterator<IFactoryData<ITask, NBTTagCompound>> getIterator() {
                List<IFactoryData<ITask, NBTTagCompound>> list = TaskRegistry.INSTANCE.getAll();
                list.sort(Comparator.comparing(o -> {
                    return o.getRegistryName().toString().toLowerCase();
                }));
                return list.iterator();
            }

            protected void queryMatches(IFactoryData<ITask, NBTTagCompound> value, String query, ArrayDeque<IFactoryData<ITask, NBTTagCompound>> results) {
                if (value.getRegistryName().toString().toLowerCase().contains(query.toLowerCase())) {
                    results.add(value);
                }
            }

            /* JADX INFO: Access modifiers changed from: protected */
            public boolean addResult(IFactoryData<ITask, NBTTagCompound> entry, int index, int cachedWidth) {
                addPanel(new PanelButtonStorage(new GuiRectangle(0, index * 16, cachedWidth, 16, 0), 1, entry.getRegistryName().toString(), entry));
                return true;
            }
        };
        cvBackground.addPanel(cvRegSearch);
        PanelVScrollBar scReg = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(-24, 48, 16, 32), 0));
        cvBackground.addPanel(scReg);
        cvRegSearch.setScrollDriverY(scReg);
        PanelTextField<String> tfSearch = new PanelTextField<>(new GuiTransform(new Vector4f(0.5f, 0.0f, 1.0f, 0.0f), new GuiPadding(8, 32, 16, -48), 0), "", FieldFilterString.INSTANCE);
        cvRegSearch.getClass();
        tfSearch.setCallback(cvRegSearch::setSearchFilter);
        tfSearch.setWatermark("Search...");
        cvBackground.addPanel(tfSearch);
        this.qtList = new CanvasScrolling(new GuiTransform(GuiAlign.HALF_LEFT, new GuiPadding(16, 32, 16, 32), 0));
        cvBackground.addPanel(this.qtList);
        PanelVScrollBar scRew = new PanelVScrollBar(new GuiTransform(new Vector4f(0.5f, 0.0f, 0.5f, 1.0f), new GuiPadding(-16, 32, 8, 32), 0));
        cvBackground.addPanel(scRew);
        this.qtList.setScrollDriverY(scRew);
        GuiTransform guiTransform = new GuiTransform(GuiAlign.TOP_CENTER, 0, 32, 0, 0, 0);
        guiTransform.setParent(cvBackground.getTransform());
        GuiTransform guiTransform2 = new GuiTransform(GuiAlign.BOTTOM_CENTER, 0, -32, 0, 0, 0);
        guiTransform2.setParent(cvBackground.getTransform());
        PanelLine paLine0 = new PanelLine(guiTransform, guiTransform2, PresetLine.GUI_DIVIDER.getLine(), 1, PresetColor.GUI_DIVIDER.getColor(), 1);
        cvBackground.addPanel(paLine0);
        refreshTasks();
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        PanelButtonStorage button = event.getButton();
        if (button.getButtonID() == 0) {
            this.field_146297_k.func_147108_a(this.parent);
            return;
        }
        if (button.getButtonID() == 1 && (button instanceof PanelButtonStorage)) {
            IFactoryData<ITask, NBTTagCompound> fact = (IFactoryData) button.getStoredValue();
            this.quest.getTasks().add(this.quest.getTasks().nextID(), fact.createNew());
            SendChanges();
            return;
        }
        if (button.getButtonID() == 2 && (button instanceof PanelButtonStorage)) {
            if (this.quest.getTasks().removeValue((ITask) button.getStoredValue())) {
                SendChanges();
                return;
            }
            return;
        }
        if (button.getButtonID() == 3 && (button instanceof PanelButtonStorage)) {
            ITask task = (ITask) button.getStoredValue();
            GuiScreen editor = task.getTaskEditor(this, new DBEntry(this.qID, this.quest));
            if (editor != null) {
                this.field_146297_k.func_147108_a(editor);
            } else {
                this.field_146297_k.func_147108_a(new GuiNbtEditor(this, task.writeToNBT(new NBTTagCompound()), value -> {
                    task.readFromNBT(value);
                    SendChanges();
                }));
            }
        }
    }

    private void refreshTasks() {
        List<DBEntry<ITask>> dbTsk = this.quest.getTasks().getEntries();
        this.qtList.resetCanvas();
        int w = this.qtList.getTransform().getWidth();
        for (int i = 0; i < dbTsk.size(); i++) {
            ITask task = (ITask) dbTsk.get(i).getValue();
            this.qtList.addPanel(new PanelButtonStorage(new GuiRectangle(0, i * 16, w - 16, 16, 0), 3, QuestTranslation.translate(task.getUnlocalisedName(), new Object[0]), task));
            this.qtList.addPanel(new PanelButtonStorage(new GuiRectangle(w - 16, i * 16, 16, 16, 0), 2, "" + ChatFormatting.RED + ChatFormatting.BOLD + "x", task));
        }
    }

    private void SendChanges() {
        NBTTagCompound payload = new NBTTagCompound();
        NBTTagList dataList = new NBTTagList();
        NBTTagCompound entry = new NBTTagCompound();
        entry.func_74768_a("questID", this.qID);
        entry.func_74782_a("config", this.quest.writeToNBT(new NBTTagCompound()));
        dataList.func_74742_a(entry);
        payload.func_74782_a("data", dataList);
        payload.func_74768_a("action", 0);
        NetQuestEdit.sendEdit(payload);
    }
}
